@@ -65,8 +65,19 @@ void openFile(const QString& path)
     g_setenv("QT_SCREEN_SCALE_FACTORS", "1", 1);
 #endif
 
+#ifdef Q_OS_LINUX
+    QByteArray ldPath = qgetenv("LD_LIBRARY_PATH");
+    qunsetenv("LD_LIBRARY_PATH");
+#endif
+
     ::openInNativeExtension(path) || ::showInGraphicalShell(path);
 
+#ifdef Q_OS_LINUX
+    if (!ldPath.isEmpty()) {
+        qputenv("LD_LIBRARY_PATH", ldPath);
+    }
+#endif
+
 #if defined(Q_OS_WIN32)
     g_setenv("QT_SCREEN_SCALE_FACTORS", factors, 1);
 #endif
@@ -1628,7 +1639,7 @@ void FileBrowserDialog::onOpenLocalCacheFolder()
          seafApplet->warningBox(tr("Unable to create cache folder"), this);
          return;
      }
-     if (!QDesktopServices::openUrl(QUrl::fromLocalFile(folder)))
+     if (!openUrl(QUrl::fromLocalFile(folder)))
          seafApplet->warningBox(tr("Unable to open cache folder"), this);
 }
 
